@@ -498,6 +498,10 @@ def main():
     )
     args = parser.parse_args()
 
+    # validate options
+    if args.update_venv and args.config_only:
+        raise Exception("You cannot specify --update-venv and --config-only both")
+
     base_dir = os.path.abspath(os.path.dirname(__file__))
 
     # get the config file
